@@ -3,9 +3,8 @@ use 5.014;
 use warnings;
 use Carp qw(confess);
 
-$FASTX::Reader::VERSION = '0.02';
-
-#ABSTRACT: A lightweight FASTA and FASTQ reader based on Heng Li's parser, to retrieve name, comments*, sequence and quality* of each record. (* if any)
+$FASTX::Reader::VERSION = '0.05';
+#ABSTRACT: A lightweight FASTA and FASTQ reader based on Heng Li's parser.
 
 
 
@@ -24,6 +23,7 @@ sub new {
     $object->{aux} = [undef];
 
     # Check if a filename was provided and not {{STDIN}}
+    # uncoverable branch false
     if (defined $self->{filename} and $self->{filename} ne '{{STDIN}}') {
       open my $fh,  '<:encoding(UTF-8)', $self->{filename} or confess "Unable to read file ", $self->{filename}, ": ", $!, "\n";
       $object->{fh} = $fh;
@@ -42,6 +42,7 @@ sub getRead {
   my $return;
   @$aux = [undef, 0] if (!(@$aux));	# remove deprecated 'defined'
   return if ($aux->[1]);
+  # uncoverable branch true
   if (!defined($aux->[0])) {
       while (<$fh>) {
           chomp;
@@ -141,7 +142,10 @@ sub getFastqRead {
 }
 
 sub getFileFormat {
+  my $self   = shift;
   my ($filename) = shift;
+  return 0 if (not defined $filename);
+  return $filename if (not -e "$filename");
   open my $f, '<:encoding(UTF-8)', "$filename" || confess "Unable to read $filename\n$!\n";
   my $first = readline($f);
   if (substr($first, 0,1) eq '>') {
@@ -172,11 +176,11 @@ __END__
 
 =head1 NAME
 
-FASTX::Reader - A lightweight FASTA and FASTQ reader based on Heng Li's parser, to retrieve name, comments*, sequence and quality* of each record. (* if any)
+FASTX::Reader - A lightweight FASTA and FASTQ reader based on Heng Li's parser.
 
 =head1 VERSION
 
-version 0.02
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -254,17 +258,6 @@ See: L<readfq repository|https://github.com/telatin/readfq>
 
 =back
 
-=head1 SEE ALSO
-
-=over 4
-
-=item L<BioX::Seq::Stream>
-
-A module to "parse FASTA and FASTQ files sequentially". This module was specifically designed to make the I<readfq()> subroutine portable,
-supporting several scripts making use of it, if a generic FASTA/FASTQ parses is needed Jeremy Volkening's C<BioX::Seq::Stream> is a well written alternative.
-
-=back
-
 =head1 CONTRIBUTORS
 
 =over 4
